Research topics
===============

This section contains descriptions of particular tools of interest to those
doing game theoretic research.

Contents:

.. toctree::
   :maxdepth: 2

   noisy_tournaments.rst
   probabilistict_end_tournaments.rst
   spatial_tournaments.rst
   morality_metrics.rst
   ecological_variant.rst
   fingerprinting.rst
